@@ -309,7 +309,7 @@ do_smooth_draw_focus(SmoothCanvas Canvas,
 
 		SmoothCanvasSetPenValues(Canvas, color, line_width, 
 						dash_pattern.Pattern[0] ? GDK_LINE_ON_OFF_DASH : GDK_LINE_SOLID,
-						GDK_JOIN_MITER, GDK_CAP_BUTT);
+						GDK_JOIN_MITER, GDK_CAP_NOT_LAST);
 	}
 
 	dash_pattern.Length = strlen(dash_pattern.Pattern);
@@ -1021,8 +1021,8 @@ do_smooth_draw_box(SmoothCanvas Canvas,
 	                               shadow_type == GTK_SHADOW_IN, Horizontal);
             }
           }
-	  
-	  do_smooth_draw_shadow(Canvas, style, state_type, shadow_type, widget, "smooth_trough", X+PART_XPADDING(part), Y+PART_YPADDING(part), 
+
+	  do_smooth_draw_shadow(Canvas, style, GTK_STATE_NORMAL, shadow_type, widget, "smooth_trough", X+PART_XPADDING(part), Y+PART_YPADDING(part), 
 				Width - PART_XPADDING(part)*2, Height - PART_YPADDING(part)*2);
       }
     } else if ((CHECK_DETAIL (detail, "button")) && widget && is_in_combo_box (widget) && (ENTRY_BUTTON_EMBED(style)))
