@@ -626,7 +626,16 @@ GDK1CanvasFrameRectangle(SmoothPrivateCanvas *Canvas,
 			{
 				if ((!Canvas->GDKPrivateCanvas.Pen.UsePattern) || (!Canvas->GDKPrivateCanvas.Pen.Pattern.Pattern[0]))
 				{
-					gdk_draw_rectangle(Canvas->GDKPrivateCanvas.Window, pen, SmoothFalse, X, Y, Width - 1, Height - 1);
+					SmoothInt line = 0;
+
+					if (Canvas->GDKPrivateCanvas.Pen.UseThickness)
+					{
+						line = Canvas->GDKPrivateCanvas.Pen.Thickness;
+					}
+
+					line /= 2;
+
+					gdk_draw_rectangle(Canvas->GDKPrivateCanvas.Window, pen, SmoothFalse, X + line, Y + line, Width - line - 1, Height - line - 1);
 				}
 				else
 				{
